type Callback = (...args: any[]) => void;

class EventBus {
  private events: Record<string, Callback[]> = {};

  on(event: string, callback: Callback): void {
    if (!this.events[event]) {
      this.events[event] = [];
    }
    this.events[event].push(callback);
  }

  off(event: string, callback: Callback): void {
    if (!this.events[event]) return;
    this.events[event] = this.events[event].filter(cb => cb !== callback);
  }

  emit(event: string, ...args: any[]): Promise<any> | void {
    if (!this.events[event]) return;
    
    const [callback] = this.events[event];
    if (callback) {
      return Promise.resolve(callback(...args));
    }
  }
}

export default new EventBus();